==> planeshift-0.3.016.tar.bz2: planeshift-0.3.016/src/server/database/mysql/characters.sql <==
# MySQL-Front 3.2  (Build 13.0)

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES */;

/*!40101 SET NAMES latin1 */;
/*!40103 SET TIME_ZONE='SYSTEM' */;

# Host: localhost    Database: planeshift
# ------------------------------------------------------
# Server version 5.0.19-nt

#
# Table structure for table characters
#

CREATE TABLE `characters` 
(
  `id` int(10) NOT NULL auto_increment,
  `name` varchar(30) NOT NULL default '',
  `lastname` varchar(30) NOT NULL default '',
  `old_lastname` varchar(30) NOT NULL default '',
  `racegender_id` smallint(5) unsigned NOT NULL default '0',
  `character_type` int(10) unsigned default '0',
  `base_strength` float(10,2) NOT NULL default '0.00',
  `base_agility` float(10,2) NOT NULL default '0.00',
  `base_endurance` float(10,2) NOT NULL default '0.00',
  `base_intelligence` float(10,2) NOT NULL default '0.00',
  `base_will` float(10,2) NOT NULL default '0.00',
  `base_charisma` float(10,2) NOT NULL default '0.00',
  `base_hitpoints_max` float(10,2) NOT NULL default '0.00',
  `mod_hitpoints` float(10,2) NOT NULL default '0.00',
  `base_mana_max` float(10,2) NOT NULL default '0.00',
  `mod_mana` float(10,2) NOT NULL default '0.00',
  `stamina_physical` float(10,2) NOT NULL default '0.00',
  `stamina_mental` float(10,2) NOT NULL default '0.00',
  `money_circles` int(10) unsigned NOT NULL default '0',
  `money_octas` int(10) unsigned NOT NULL default '0',
  `money_hexas` int(10) unsigned NOT NULL default '0',
  `money_trias` int(10) unsigned NOT NULL default '0',
  `bank_money_circles` int(10) unsigned NOT NULL default '0',
  `bank_money_octas` int(10) unsigned NOT NULL default '0',
  `bank_money_hexas` int(10) unsigned NOT NULL default '0',
  `bank_money_trias` int(10) unsigned NOT NULL default '0',
  `loc_sector_id` int(10) unsigned NOT NULL default '0',
  `loc_x` float(10,2) NOT NULL default '0.00',
  `loc_y` float(10,2) NOT NULL default '0.00',
  `loc_z` float(10,2) NOT NULL default '0.00',
  `loc_yrot` float(10,2) NOT NULL default '0.00',
  `guild_member_of` int(10) unsigned NOT NULL default '0',
  `guild_level` tinyint(1) unsigned NOT NULL default '0',
  `guild_points` int(10) unsigned NOT NULL default '0',
  `guild_public_notes` varchar(255) default NULL,
  `guild_private_notes` varchar(255) default '0',
  `last_login` datetime default NULL,
  `faction_standings` blob,
  `progression_script` blob,
  `npc_spawn_rule` int(10) unsigned default '0',
  `npc_master_id` int(10) unsigned default '0',
  `npc_impervious_ind` char(1) NOT NULL default 'N',
  `account_id` int(10) unsigned NOT NULL default '0',
  `time_connected_sec` int(10) unsigned NOT NULL default '0',
  `npc_addl_loot_category_id` int(10) unsigned default '0',
  `experience_points` int(10) unsigned default '0',
  `progression_points` int(10) unsigned default '0',
  `duel_points` float(10,2) NOT NULL default '0.00',
  `description` text,
  `kill_exp` int(5) NOT NULL default '10',
  `animal_affinity` text,
  `help_event_flags` int(11) unsigned default '0' COMMENT 'Bit field of which instruction events have played for him.',
  PRIMARY KEY  (`id`),
  KEY `account_id` (`account_id`),
  KEY `name` (`name`)
) ENGINE=MyISAM ;

#
# Dumping data for table characters
#

INSERT INTO `characters` VALUES (1,'Guest','Char','',0,0,144,40,44,40,40,40,0,100,0,100,216,200,34,40,10,134,100,100,100,100,3,-43.86,-0.01,-152.3,1.5,0,0,0,NULL,NULL,'0000-00-00 00:00:00','1,-50,2,50','',0,0,'N',3,2604,0,180,18,0,'Was born in a jar',10,'',0);
INSERT INTO `characters` VALUES (2,'Vengeance','IsMine','',0,0,160,60,60,60,60,60,0,280,0,120,200,200,34,40,10,134,0,0,0,0,3,-28.22,0,-160.07,-0.42,0,0,0,NULL,NULL,'2006-03-21 00:54:28','1,-40,2,50','',0,0,'N',1,14882,0,150,10,0,'Grew up on a ice mountain',10,'<category attribute="Lifecycle" name="Daylight" value="10" /><category attribute="Type" name="Animal" value="5" />',0);
INSERT INTO `characters` VALUES (3,'Acraig','Newfie','',2,0,144,40,44,40,40,40,0,100,0,100,216,200,34,40,10,134,100,100,100,100,3,-61.32,-0.01,-187.16,0,0,0,0,NULL,NULL,'0000-00-00 00:00:00','1,-30,2,30','',0,0,'N',5,3798,0,150,1000,0,'description',1000,'',0);
INSERT INTO `characters` VALUES (4,'MaleEnki','','',1,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,0,0,-180,0,0,0,0,'','',NULL,'1,30,2,-30','',1,4,'N',9,0,0,0,0,0,'description',10,'',0);
INSERT INTO `characters` VALUES (5,'Smith','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-53.54,0,-155.11,0,0,0,0,'','',NULL,'','',1,5,'N',9,0,0,0,0,0,'description',10,'',0);
INSERT INTO `characters` VALUES (6,'Fighter1','','',2,1,65,65,65,60,60,60,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,0,0,-160,0,0,0,0,'','',NULL,'1,30,2,-30','',1,4,'N',9,0,2,0,0,0,'description',10,'',0);
INSERT INTO `characters` VALUES (7,'Fighter2','','',3,1,100,100,100,100,100,100,200,200,100,100,100,100,100,100,100,100,100,100,100,100,3,-92,0,-266,0,0,0,0,'','',NULL,'1,35,2,-35','',1,4,'N',9,0,2,0,0,0,'description',10,'',0);
INSERT INTO `characters` VALUES (8,'Merchant','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-46.54,0,-151.11,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',1,8,'N',9,0,0,0,0,0,'description',500,'',0);
INSERT INTO `characters` VALUES (9,'Lady','Aren','',14,0,44,40,44,40,40,40,0,100,0,100,216,200,34,40,10,134,100,100,100,100,3,-43.86,-0.01,-152.3,1.5,0,0,0,NULL,NULL,'0000-00-00 00:00:00','1,-50,2,50','',0,0,'N',1,2604,0,180,18,0,'The love of Guest Char.',10,'',0);
INSERT INTO `characters` VALUES (10,'Pet','Sample','',23,2,60,60,60,60,60,60,60,100,100,100,200,200,100,100,100,100,100,100,100,100,3,0,0,0,0,0,0,0,'','','0000-00-00 00:00:00','1,-50,2,50','',0,0,'N',9,0,0,10000,1000,0,'A Pet Sample',10000,NULL,0);
INSERT INTO `characters` VALUES (11,'Guest\'s','Pet Sample','',23,2,60,60,60,60,60,60,60,100,100,100,200,200,100,100,100,100,100,100,100,100,3,-43.86,-0.01,-152.8,1.5,0,0,0,'','','0000-00-00 00:00:00','1,-50,2,50','',0,0,'N',9,0,0,10000,1000,0,'A Pet Sample',10000,NULL,0);
INSERT INTO `characters` VALUES (12,'QuestMaster1','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-30,0,-150,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',1,8,'N',9,0,0,0,0,0,'Used for quest testing. Type \"step1\" to start Test.',500,'',0);
INSERT INTO `characters` VALUES (13,'QuestMaster2','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-35,0,-150,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',1,8,'N',9,0,0,0,0,0,'Used for quest testing. Type \"step1\" to start Test.',500,'',0);
INSERT INTO `characters` VALUES (14,'DictMaster1','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-40,0,-150,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',1,8,'N',9,0,0,0,0,0,'Used for quest testing. Type \"step1\" to start Test.',500,'',0);
INSERT INTO `characters` VALUES (15,'DictMaster2','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-45,0,-150,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',1,8,'N',9,0,0,0,0,0,'Used for quest testing. Type \"step1\" to start Test.',500,'',0);
INSERT INTO `characters` VALUES (20,'Tribe1Member1','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-45,0,-150,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',1,8,'N',9,0,0,0,0,0,'Tribe member. Used in tribe testing.',500,'',0);
INSERT INTO `characters` VALUES (21,'Tribe1Member2','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-75,0,-180,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',1,8,'N',9,0,0,0,0,0,'Tribe member. Used in tribe testing.',500,'',0);
INSERT INTO `characters` VALUES (22,'Tribe1Member3','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-80,0,-180,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',1,8,'N',9,0,0,0,0,0,'Tribe member. Used in tribe testing.',500,'',0);
INSERT INTO `characters` VALUES (23,'Tribe1Member4','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-85,0,-180,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',1,8,'N',9,0,0,0,0,0,'Tribe member. Used in tribe testing.',500,'',0);

==> planeshift-0.3.017.tar.bz2: planeshift-0.3.017/src/server/database/mysql/characters.sql <==
# MySQL-Front 3.2  (Build 13.0)

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES */;

/*!40101 SET NAMES latin1 */;
/*!40103 SET TIME_ZONE='SYSTEM' */;

# Host: localhost    Database: planeshift
# ------------------------------------------------------
# Server version 5.0.19-nt

#
# Table structure for table characters
#

CREATE TABLE `characters` 
(
  `id` int(10) NOT NULL auto_increment,
  `name` varchar(30) NOT NULL default '',
  `lastname` varchar(30) NOT NULL default '',
  `old_lastname` varchar(30) NOT NULL default '',
  `racegender_id` smallint(5) unsigned NOT NULL default '0',
  `character_type` int(10) unsigned default '0',
  `base_strength` float(10,2) NOT NULL default '0.00',
  `base_agility` float(10,2) NOT NULL default '0.00',
  `base_endurance` float(10,2) NOT NULL default '0.00',
  `base_intelligence` float(10,2) NOT NULL default '0.00',
  `base_will` float(10,2) NOT NULL default '0.00',
  `base_charisma` float(10,2) NOT NULL default '0.00',
  `base_hitpoints_max` float(10,2) NOT NULL default '0.00',
  `mod_hitpoints` float(10,2) NOT NULL default '0.00',
  `base_mana_max` float(10,2) NOT NULL default '0.00',
  `mod_mana` float(10,2) NOT NULL default '0.00',
  `stamina_physical` float(10,2) NOT NULL default '0.00',
  `stamina_mental` float(10,2) NOT NULL default '0.00',
  `money_circles` int(10) unsigned NOT NULL default '0',
  `money_octas` int(10) unsigned NOT NULL default '0',
  `money_hexas` int(10) unsigned NOT NULL default '0',
  `money_trias` int(10) unsigned NOT NULL default '0',
  `bank_money_circles` int(10) unsigned NOT NULL default '0',
  `bank_money_octas` int(10) unsigned NOT NULL default '0',
  `bank_money_hexas` int(10) unsigned NOT NULL default '0',
  `bank_money_trias` int(10) unsigned NOT NULL default '0',
  `loc_sector_id` int(10) unsigned NOT NULL default '0',
  `loc_x` float(10,2) NOT NULL default '0.00',
  `loc_y` float(10,2) NOT NULL default '0.00',
  `loc_z` float(10,2) NOT NULL default '0.00',
  `loc_yrot` float(10,2) NOT NULL default '0.00',
  `guild_member_of` int(10) unsigned NOT NULL default '0',
  `guild_level` tinyint(1) unsigned NOT NULL default '0',
  `guild_points` int(10) unsigned NOT NULL default '0',
  `guild_public_notes` varchar(255) default NULL,
  `guild_private_notes` varchar(255) default '0',
  `last_login` datetime default NULL,
  `faction_standings` blob,
  `progression_script` blob,
  `npc_spawn_rule` int(10) unsigned default '0',
  `npc_master_id` int(10) unsigned default '0',
  `npc_impervious_ind` char(1) NOT NULL default 'N',
  `account_id` int(10) unsigned NOT NULL default '0',
  `time_connected_sec` int(10) unsigned NOT NULL default '0',
  `npc_addl_loot_category_id` int(10) unsigned default '0',
  `experience_points` int(10) unsigned default '0',
  `progression_points` int(10) unsigned default '0',
  `duel_points` float(10,2) NOT NULL default '0.00',
  `description` text,
  `kill_exp` int(5) NOT NULL default '10',
  `animal_affinity` text,
  `help_event_flags` int(11) unsigned default '0' COMMENT 'Bit field of which instruction events have played for him.',
  PRIMARY KEY  (`id`),
  KEY `account_id` (`account_id`),
  KEY `name` (`name`)
) ENGINE=MyISAM ;

#
# Dumping data for table characters
#

INSERT INTO `characters` VALUES (1,'Guest','Char','',0,0,144,40,44,40,40,40,0,100,0,100,216,200,34,40,10,134,100,100,100,100,3,-43.86,-0.01,-152.3,1.5,0,0,0,NULL,NULL,'0000-00-00 00:00:00','1,-50,2,50','',0,0,'N',3,2604,0,180,18,0,'Was born in a jar',10,'',0);
INSERT INTO `characters` VALUES (2,'Vengeance','IsMine','',0,0,160,60,60,60,60,60,0,280,0,120,200,200,34,40,10,134,0,0,0,0,3,-28.22,0,-160.07,-0.42,0,0,0,NULL,NULL,'2006-03-21 00:54:28','1,-40,2,50','',0,0,'N',1,14882,0,150,10,0,'Grew up on a ice mountain',10,'<category attribute="Lifecycle" name="Daylight" value="10" /><category attribute="Type" name="Animal" value="5" />',0);
INSERT INTO `characters` VALUES (3,'Acraig','Newfie','',2,0,144,40,44,40,40,40,0,100,0,100,216,200,34,40,10,134,100,100,100,100,3,-61.32,-0.01,-187.16,0,0,0,0,NULL,NULL,'0000-00-00 00:00:00','1,-30,2,30','',0,0,'N',5,3798,0,150,1000,0,'description',1000,'',0);
INSERT INTO `characters` VALUES (4,'MaleEnki','','',1,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,0,0,-180,0,0,0,0,'','',NULL,'1,30,2,-30','',1,4,'N',9,0,0,0,0,0,'description',10,'',0);
INSERT INTO `characters` VALUES (5,'Smith','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-53.54,0,-155.11,0,0,0,0,'','',NULL,'','',1,5,'N',9,0,0,0,0,0,'description',10,'',0);
INSERT INTO `characters` VALUES (6,'Fighter1','','',2,1,65,65,65,60,60,60,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,0,0,-160,0,0,0,0,'','',NULL,'1,30,2,-30','',1,4,'N',9,0,2,0,0,0,'description',10,'',0);
INSERT INTO `characters` VALUES (7,'Fighter2','','',3,1,100,100,100,100,100,100,200,200,100,100,100,100,100,100,100,100,100,100,100,100,3,-92,0,-266,0,0,0,0,'','',NULL,'1,35,2,-35','',1,4,'N',9,0,2,0,0,0,'description',10,'',0);
INSERT INTO `characters` VALUES (8,'Merchant','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-46.54,0,-151.11,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',1,8,'N',9,0,0,0,0,0,'description',500,'',0);
INSERT INTO `characters` VALUES (9,'Lady','Aren','',14,0,44,40,44,40,40,40,0,100,0,100,216,200,34,40,10,134,100,100,100,100,3,-43.86,-0.01,-152.3,1.5,0,0,0,NULL,NULL,'0000-00-00 00:00:00','1,-50,2,50','',0,0,'N',1,2604,0,180,18,0,'The love of Guest Char.',10,'',0);
INSERT INTO `characters` VALUES (10,'Pet','Sample','',23,2,60,60,60,60,60,60,60,100,100,100,200,200,100,100,100,100,100,100,100,100,3,0,0,0,0,0,0,0,'','','0000-00-00 00:00:00','1,-50,2,50','',0,0,'N',9,0,0,10000,1000,0,'A Pet Sample',10000,NULL,0);
INSERT INTO `characters` VALUES (11,'Guest\'s','Pet Sample','',23,2,60,60,60,60,60,60,60,100,100,100,200,200,100,100,100,100,100,100,100,100,3,-43.86,-0.01,-152.8,1.5,0,0,0,'','','0000-00-00 00:00:00','1,-50,2,50','',0,0,'N',9,0,0,10000,1000,0,'A Pet Sample',10000,NULL,0);
INSERT INTO `characters` VALUES (12,'QuestMaster1','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-30,0,-150,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',1,8,'N',9,0,0,0,0,0,'Used for quest testing. Type \"step1\" to start Test.',500,'',0);
INSERT INTO `characters` VALUES (13,'QuestMaster2','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-35,0,-150,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',1,8,'N',9,0,0,0,0,0,'Used for quest testing. Type \"step1\" to start Test.',500,'',0);
INSERT INTO `characters` VALUES (14,'DictMaster1','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-40,0,-150,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',1,14,'N',9,0,0,0,0,0,'Used for quest testing. Type \"step1\" to start Test.',500,'',0);
INSERT INTO `characters` VALUES (15,'DictMaster2','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-45,0,-150,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',1,14,'N',9,0,0,0,0,0,'Used for quest testing. Type \"step1\" to start Test.',500,'',0);
INSERT INTO `characters` VALUES (20,'TribeMember','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-45,0,-150,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',0,20,'N',9,0,0,0,0,0,'Tribe member. Used in tribe testing.',500,'',0);
INSERT INTO `characters` VALUES (21,'MoveMaster1','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-30.0,0.0,-130.0,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',1,21,'N',9,0,0,0,0,0,'Used to test movement.',500,'',0);
INSERT INTO `characters` VALUES (22,'MoveMaster2','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-35.0,0.0,-130.0,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',1,8,'N',9,0,0,0,0,0,'Used to test meovement.',500,'',0);
INSERT INTO `characters` VALUES (23,'MoveMaster3','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-40.0,0.0,-130.0,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',1,8,'N',9,0,0,0,0,0,'Used to test meovement.',500,'',0);
INSERT INTO `characters` VALUES (24,'MoveMaster4','','',7,1,44,40,44,40,40,40,50,100,100,100,100,100,100,100,100,100,100,100,100,100,3,-45.0,0.0,-130.0,0,0,0,0,'','',NULL,'1,30,3,30,4,-50','',1,8,'N',9,0,0,0,0,0,'Used to test meovement.',500,'',0);
